<?php
/**
* Erzeugt ein Array für das Infomessage-Template.
*
* Diese Funktion erzeugt eine Array für unsere Templateengine die dann
* die Infomessage-Template-Datei "info.tpl" läd. Der Parameter gibt
* dabei die Nachricht an die angezeigt werden soll.
*
* @param msg Die Nachricht die angezeigt werden soll.
* @return Das Array für unsere Templateengine.
*/
function showInfo($msg)
{
  $ret                = array();
  $ret['filename']    = 'info.tpl';
  $ret['data']        = array();
  $ret['data']['msg'] = $msg;
  return $ret;
}
/**
 * Liefert die Benutzer-ID zurück.
 *
 * Diese Funktion liefert die Benutzer-ID des angemeldeten Benutzers zurück.
 * Falls kein Benutzer angemeldet ist liefert diese Funktion den Wert false
 * zurück. Der Parameter gibt dabei das MySQLi-Objekt an in der nach
 * dem Login geprüft werden soll. Es werden dabei die Cookies "UserID" und
 * "Password" ausgelesen. Bei einem MySQL-Fehler wird ein String mit
 * der Fehlermeldung zurückgeliefert.
 *
 * @param db Das MySQLi-Objekt auf dem gearbeitet wird.
 * @return false wenn der Benutzer nicht eingeloggt ist, die ID des Benutzers
 * wenn er eingeloggt ist oder ein string wenn eine Fehlermeldung
 * auftrat.
*/

function getUserID($db)
{
  if (!is_object($db))
  {
    return false;
  }

  if (!($db instanceof MySQLi))
  {
    return false;
  }
  if (!isset ($_COOKIE['UserID'], $_COOKIE['Password']))
  {
    return false;
  }

  $sql = 'SELECT
           ID
          FROM
           User
          WHERE
           ID = ? AND Password = ?';
  $stmt = $db->prepare($sql);
  if (!$stmt)
  {
    return $db->error;
  }

  $stmt->bind_param('is', $_COOKIE['UserID'], $_COOKIE['Password']);

  if (!$stmt->execute())
  {
    $str = $stmt->error;
    $stmt->close();
    return $str;
  }

  $stmt->bind_result($UserID);
  if (!$stmt->fetch())
  {
    $stmt->close();
    return false;
  }
  $stmt->close();
  return $UserID;
}
?>